#ifndef NT2_INCLUDE_FUNCTIONS_LCM_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_LCM_HPP_INCLUDED

#include <nt2/combinatorial/include/functions/lcm.hpp>

#endif
